@@ -22,7 +22,7 @@ class PolarityDistributionFB:
     This class computes the polarity of the texts.
     """
 
-    def __init__(self, df_comments, df_pages, groups):
+    def __init__(self, df_comments, df_pages, groups, r_group=False):
         """
         This method stores the input DataFrames and checks that they are not empty'.
 
@@ -41,12 +41,16 @@ class PolarityDistributionFB:
             type: dict
             Maps the groups (client, competition, archetype, trends) to the
             corresponding page ids for each group.
+        r_group:
+            type: bool
+            varibale that indicates if the class return the column group
         """
         METHOD_NAME = "__init__"
         df_comments_full = deepcopy(df_comments)
         self.df_comments_full = df_comments_full
         self.df_pages = df_pages
         self.groups = groups
+        self.r_group = r_group
         try:
             if df_comments.empty:
                 print("Warning: input data DataFrame is empty.")
@@ -103,6 +107,7 @@ class PolarityDistributionFB:
             ):
                 self.df_comments_full = Polarity().polarity(self.df_comments_full)
                 df_comments = self.df_comments_full
+                df_comments = df_comments.dropna(subset=["polarity"])
                 return df_comments
         except Exception as e:
             print(e)
@@ -174,6 +179,7 @@ class PolarityDistributionFB:
             if "group" not in self.df_comments_full.keys():
                 self.df_comments_full["group"] = "no group"
             self.df_comments_full["all"] = "all groups"
+            self.df_comments_full = self.df_comments_full.dropna(subset=["polarity"])
 
         # groups texts and returns data frame
         try:
@@ -238,7 +244,7 @@ class PolarityDistributionFB:
             elif group_by == "time-account":
                 df_groupedpolarity = (
                     self.df_comments_full.groupby(
-                        ["created_time", "page_id", "page_name"]
+                        ["created_time", "page_id", "page_name", "post_id", "group"]
                     )["polarity"]
                     .value_counts()
                     .unstack()
@@ -250,9 +256,18 @@ class PolarityDistributionFB:
                 df_groupedpolarity = df_groupedpolarity.reset_index().rename(
                     columns={"page_id": "_object_id", "page_name": "_object_name"}
                 )
-                return df_groupedpolarity.reset_index()[
-                    ["created_time", "_object_id", "_object_name", "sentiment"]
+                df_groupedpolarity = df_groupedpolarity.sort_values(by=["created_time"])
+
+                columns = [
+                    "created_time",
+                    "_object_id",
+                    "_object_name",
+                    "sentiment",
+                    "post_id",
                 ]
+                if self.r_group == True:
+                    columns.append("group")
+                return df_groupedpolarity[columns].reset_index()
             else:
                 print(
                     f"Warning: {group_by} Invalid parameter value for parameter group_by, grouping by all"
