@@ -127,7 +127,7 @@ class MostEffectiveContentIG:
 
                 self.df_posts_full = df_posts_full
                 self.len_posts_full = len(self.df_posts_full)
-            except Exception as e:
+            except Exception:
                 exception_type = sys.exc_info()[0]
                 print(ERR_SYS + str(exception_type))
                 print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
@@ -171,6 +171,7 @@ class MostEffectiveContentIG:
                 self.df_posts_full.owner_id.isin(account_ids)
             ][
                 [
+                    "owner_id",
                     "owner_username",
                     "shortcode",
                     "caption",
@@ -184,6 +185,7 @@ class MostEffectiveContentIG:
                 self.df_posts_full.owner_username.isin(account_names)
             ][
                 [
+                    "owner_id",
                     "owner_username",
                     "shortcode",
                     "caption",
@@ -194,6 +196,7 @@ class MostEffectiveContentIG:
         else:
             df_most_eff_posts_ig = deepcopy(self.df_posts_full)[
                 [
+                    "owner_id",
                     "owner_username",
                     "shortcode",
                     "caption",
@@ -218,6 +221,7 @@ class MostEffectiveContentIG:
             print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}\n")
             return pd.DataFrame(
                 columns=[
+                    "owner_id",
                     "owner_username",
                     "shortcode",
                     "caption",
